@@ -11,6 +11,7 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
+#include <clocale>
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -30,35 +31,42 @@
 
 #include "tokodon-version.h"
 
-#include "account.h"
-#include "accountmanager.h"
-#include "accountmodel.h"
-#include "attachmenteditormodel.h"
-#include "blurhashimageprovider.h"
-#include "clipboard.h"
+#include "account/account.h"
+#include "account/accountmanager.h"
+#include "account/profileeditor.h"
+#include "account/socialgraphmodel.h"
+#include "admin/accounttoolmodel.h"
+#include "admin/adminaccountinfo.h"
+#include "admin/federationtoolmodel.h"
 #include "config.h"
-#include "conversationmodel.h"
-#include "filehelper.h"
-#include "followrequestmodel.h"
-#include "languagemodel.h"
-#include "linkpaginatedtimelinemodel.h"
-#include "maintimelinemodel.h"
-#include "networkaccessmanagerfactory.h"
-#include "networkcontroller.h"
-#include "networkrequestprogress.h"
-#include "notificationmodel.h"
-#include "poll.h"
-#include "polltimemodel.h"
-#include "post.h"
-#include "posteditorbackend.h"
-#include "profileeditor.h"
-#include "searchmodel.h"
-#include "tagsmodel.h"
-#include "threadmodel.h"
-#include "timelinemodel.h"
+#include "conversation/conversationmodel.h"
+#include "editor/attachmenteditormodel.h"
+#include "editor/languagemodel.h"
+#include "editor/polltimemodel.h"
+#include "editor/posteditorbackend.h"
+#include "network/networkaccessmanagerfactory.h"
+#include "network/networkcontroller.h"
+#include "network/networkrequestprogress.h"
+#include "search/searchmodel.h"
+#include "timeline/accountmodel.h"
+#include "timeline/maintimelinemodel.h"
+#include "timeline/notificationmodel.h"
+#include "timeline/poll.h"
+#include "timeline/post.h"
+#include "timeline/tagstimelinemodel.h"
+#include "timeline/threadmodel.h"
+#include "utils/blurhashimageprovider.h"
+#include "utils/clipboard.h"
+#include "utils/filehelper.h"
+#include "utils/mpvplayer.h"
+#include "timeline/tagsmodel.h"
 
 #ifdef HAVE_COLORSCHEME
-#include "colorschemer.h"
+#include "utils/colorschemer.h"
+#endif
+
+#ifdef Q_OS_WINDOWS
+#include <Windows.h>
 #endif
 
 #ifdef Q_OS_ANDROID
@@ -83,10 +91,12 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-    if (QIcon::themeName().contains("dark")) {
-        QIcon::setFallbackThemeName("tokodon-dark");
-    } else {
+    // Breeze theme needs to be the "primary" theme or else icons do not get recolored
+    // Non-Breeze themes (like Adwaita) do not load our icons properly unless tokodon is the main icon theme.
+    if (QIcon::themeName() == "breeze") {
         QIcon::setFallbackThemeName("tokodon");
+    } else {
+        QIcon::setThemeName("tokodon");
     }
 #endif
 
@@ -119,6 +129,14 @@ int main(int argc, char *argv[])
     KAboutData::setApplicationData(about);
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.tokodon")));
 
+    QCommandLineParser parser;
+    parser.setApplicationDescription(i18n("Client for the decentralized social network: mastodon"));
+    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports web+ap: url scheme"));
+
+    about.setupCommandLine(&parser);
+    parser.process(app);
+    about.processCommandLine(&parser);
+
 #ifdef HAVE_KDBUSADDONS
     KDBusService service(KDBusService::Unique);
 #endif
@@ -132,16 +150,22 @@ int main(int argc, char *argv[])
     }
 #endif
 
+    // Qt sets the locale in the QGuiApplication constructor, but libmpv
+    // requires the LC_NUMERIC category to be set to "C", so change it back.
+    setlocale(LC_NUMERIC, "C");
+
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Config", config);
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Controller", &NetworkController::instance());
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "AccountManager", &AccountManager::instance());
-    qmlRegisterType<MainTimelineModel>("org.kde.kmasto", 1, 0, "TimelineModel");
-    qmlRegisterType<LinkPaginationTimelineModel>("org.kde.kmasto", 1, 0, "LinkPaginationTimelineModel");
+    qmlRegisterType<MainTimelineModel>("org.kde.kmasto", 1, 0, "MainTimelineModel");
     qmlRegisterType<SearchModel>("org.kde.kmasto", 1, 0, "SearchModel");
-    qmlRegisterType<FollowRequestModel>("org.kde.kmasto", 1, 0, "FollowRequestModel");
+    qmlRegisterType<SocialGraphModel>("org.kde.kmasto", 1, 0, "SocialGraphModel");
+    qmlRegisterType<AccountsToolModel>("org.kde.kmasto", 1, 0, "AccountsToolModel");
+    qmlRegisterType<FederationToolModel>("org.kde.kmasto", 1, 0, "FederationToolModel");
+    qmlRegisterType<TagsModel>("org.kde.kmasto", 1, 0, "TagsModel");
     qmlRegisterType<ThreadModel>("org.kde.kmasto", 1, 0, "ThreadModel");
     qmlRegisterType<ConversationModel>("org.kde.kmasto", 1, 0, "ConversationModel");
-    qmlRegisterType<TagsModel>("org.kde.kmasto", 1, 0, "TagsModel");
+    qmlRegisterType<TagsTimelineModel>("org.kde.kmasto", 1, 0, "TagsTimelineModel");
     qmlRegisterType<AccountModel>("org.kde.kmasto", 1, 0, "AccountModel");
     qmlRegisterType<ProfileEditorBackend>("org.kde.kmasto", 1, 0, "ProfileEditorBackend");
     qmlRegisterType<NetworkRequestProgress>("org.kde.kmasto", 1, 0, "NetworkRequestProgress");
@@ -154,19 +178,26 @@ int main(int argc, char *argv[])
         return engine->toScriptValue(KAboutData::applicationData());
     });
     qRegisterMetaType<Account *>("Account*");
+    qRegisterMetaType<FederationInfo>("FederationInfo");
     qRegisterMetaType<AbstractAccount *>("AbstractAccount*");
     qRegisterMetaType<Identity *>("Identity*");
+    qRegisterMetaType<AdminAccountInfo *>("AdminAccountInfo*");
     qRegisterMetaType<AttachmentEditorModel *>("AttachmentEditorModel*");
     qRegisterMetaType<Post *>("Post*");
+    qRegisterMetaType<Tag *>("Tag*");
     qRegisterMetaType<Poll *>("Poll*");
     qRegisterMetaType<Card *>("Card*");
+    qRegisterMetaType<Application *>("Application*");
     qRegisterMetaType<QNetworkReply *>("QNetworkReply*");
     qRegisterMetaType<Relationship *>("Relationship*");
+    qmlRegisterUncreatableType<Tag>("org.kde.kmasto", 1, 0, "Tag", "ENUM");
     qmlRegisterUncreatableType<Post>("org.kde.kmasto", 1, 0, "Post", "ENUM");
+    qmlRegisterUncreatableType<AdminAccountInfo>("org.kde.kmasto", 1, 0, "AdminAccountInfo", "ENUM");
     qmlRegisterUncreatableType<Attachment>("org.kde.kmasto", 1, 0, "Attachment", "ENUM");
     qmlRegisterUncreatableType<Notification>("org.kde.kmasto", 1, 0, "Notification", "ENUM");
     qmlRegisterSingletonType(QUrl("qrc:/content/ui/Navigation.qml"), "org.kde.kmasto", 1, 0, "Navigation");
     qmlRegisterType<LanguageModel>("org.kde.kmasto", 1, 0, "LanguageModel");
+    qmlRegisterType<MpvPlayer>("org.kde.kmasto", 1, 0, "MpvPlayer");
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
@@ -175,14 +206,6 @@ int main(int argc, char *argv[])
     NetworkAccessManagerFactory namFactory;
     engine.setNetworkAccessManagerFactory(&namFactory);
 
-    QCommandLineParser parser;
-    parser.setApplicationDescription(i18n("Client for the decentralized social network: mastodon"));
-    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports web+ap: url scheme"));
-
-    about.setupCommandLine(&parser);
-    parser.process(app);
-    about.processCommandLine(&parser);
-
     // Controller::instance().setAboutData(about);
 
     engine.addImageProvider(QLatin1String("blurhash"), new BlurhashImageProvider);
